@@ -14,21 +14,33 @@ class TestStop_impl(TestCase):
         self.assertEqual(stop.get_name(), name)
         self.assertEqual(stop.get_coords(), coords)
 
+    def test_eq(self):
+        name = "Stop"
+        coords = (37.574604,55.499970)
+        name2 = "Stop"
+        coords2 = (37.5746041,55.4999701)
+        name3 = "Stop"
+        coords3 = (37.574605,55.499971)
+        stop = Stop_impl(name,coords)
+        stop2 = Stop_impl(name2,coords2)
+        stop3 = Stop_impl(name3,coords3)
+        self.assertTrue(stop==stop2)
+        self.assertFalse(stop==stop3)
 
 class TestStop_builder_impl(TestCase):
     def test_builder(self):
         name = "Stop"
-        stop = Stop_builder_impl().set_name(name).set_coords((10,20)).build()
+        stop = Stop_builder_impl().set_name(name).set_coords((10, 20)).build()
 
         self.assertEqual(stop.get_name(), name)
-        self.assertEqual(stop.get_coords(),(10,20))
+        self.assertEqual(stop.get_coords(), (10, 20))
 
     def test_builder_reverse(self):
         name = "StopStop"
-        stop = Stop_builder_impl().set_coords((10,20)).set_name(name).build()
+        stop = Stop_builder_impl().set_coords((10, 20)).set_name(name).build()
 
         self.assertEqual(stop.get_name(), name)
-        self.assertEqual(stop.get_coords(),(10,20))
+        self.assertEqual(stop.get_coords(), (10, 20))
 
 
 class TestTimetable_stop_time_t_mos_ru(TestCase):
@@ -208,8 +220,8 @@ class TestTimetable_t_mos_ru(TestCase):
             Timetable_stop_time_t_mos_ru(time(10, 12), "Red"),
             Timetable_stop_time_t_mos_ru(time(20, 30), None),
         ]
-        stop = Timetable_stop_builder_t_mos_ru().set_name('ул. Иванова').set_coords([20,30]).\
-            add_item_timetable(times[0].get_time(),times[0].get_color_special_flight()).\
+        stop = Timetable_stop_builder_t_mos_ru().set_name('ул. Иванова').set_coords([20, 30]). \
+            add_item_timetable(times[0].get_time(), times[0].get_color_special_flight()). \
             add_item_timetable(times[1].get_time()).build()
 
         stops = [
@@ -252,8 +264,8 @@ class TestTimetable_builder_t_mos_ru(TestCase):
             Timetable_stop_time_t_mos_ru(time(10, 12), "Red"),
             Timetable_stop_time_t_mos_ru(time(20, 30), None),
         ]
-        stop = Timetable_stop_builder_t_mos_ru().set_name('ул. Иванова').set_coords([20,30]).\
-            add_item_timetable(times[0].get_time(),times[0].get_color_special_flight()).\
+        stop = Timetable_stop_builder_t_mos_ru().set_name('ул. Иванова').set_coords([20, 30]). \
+            add_item_timetable(times[0].get_time(), times[0].get_color_special_flight()). \
             add_item_timetable(times[1].get_time()).build()
         stops = [
             stop
